# Building Blocks of Metanno

This page provides an overview of the base components available in Metanno.

<!-- --8<-- [start:components] -->

| Component                                   | Description                                                |
|---------------------------------------------|------------------------------------------------------------|
| [AnnotatedText][metanno.ui.AnnotatedText]   | View and interact with a text with optional annotations.   |
| [AnnotatedImage][metanno.ui.AnnotatedImage] | View and interact with an image with optional annotations. |
| [Table][metanno.ui.Table]                   | View and interact with a table                             |

<!-- --8<-- [end:components] -->
